@@ -1,6 +1,9 @@
 from urllib.parse import quote, unquote
 import html
 
+from wapitiCore.net.web import Request, make_absolute
+from wapitiCore.net.response import Response
+
 
 def encode(params_list):
     """Encode a sequence of two-element lists or dictionary into a URL query string."""
@@ -9,7 +12,7 @@ def encode(params_list):
         # not safe: '&=#' with of course quotes...
         param_name = quote(param_name, safe='/%[]:;$()+,!?*')
         param_value = quote(param_value, safe='/%[]:;$()+,!?*')
-        encoded_params.append("%s=%s" % (param_name, param_value))
+        encoded_params.append(f"{param_name}={param_value}")
     return "&".join(encoded_params)
 
 
